"""Message Center info API method."""
from ibsng.handler.handler import Handler


class userSearchSentMessage(Handler):
    """Message Center info method class."""

    def setup(self, conds, from_, to_, order_by, desc):
        """Setup required parameters.

        :param dict conds: 
        :param int from: 
        :param int to: 
        :param choice order_by: 
        :param bool desc: descending
    
        :return: void
        :rtype: void
        """
        self.conds = conds
        self.from_ = from_
        self.to_ = to_
        self.order_by = order_by
        self.desc = desc



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class adminDeleteMessage(Handler):
    """Message Center info method class."""

    def setup(self, message_ids, target_box):
        """Setup required parameters.

        :param int message_ids: 
        :param choice target_box: 

        :return: None
        :rtype: None
        """
        self.message_ids = message_ids
        self.target_box = target_box



""" info API method."""
from ibsng.handler.handler import Handler


class deleteGateway(Handler):
    """ info method class."""

    def setup(self, gateway_name):
        """Setup required parameters.

        :param str gateway_name: 
    
        :return: void
        :rtype: void
        """
        self.gateway_name = gateway_name



""" info API method."""
from ibsng.handler.handler import Handler


class deleteNotificationProfile(Handler):
    """ info method class."""

    def setup(self, notification_profile_name):
        """Setup required parameters.

        :param  notification_profile_name: 
    
        :return: void
        :rtype: void
        """
        self.notification_profile_name = notification_profile_name



""" info API method."""
from ibsng.handler.handler import Handler


class updateNotificationProfile(Handler):
    """ info method class."""

    def setup(self, notification_profile_id, notification_profile_name, notification_profile_comment):
        """Setup required parameters.

        :param int notification_profile_id: 
        :param str notification_profile_name: 
        :param str notification_profile_comment: 
    
        :return: void
        :rtype: void
        """
        self.notification_profile_id = notification_profile_id
        self.notification_profile_name = notification_profile_name
        self.notification_profile_comment = notification_profile_comment



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class addNewProvider(Handler):
    """Message Center info method class."""

    def setup(self, provider_type, provider_name, msg_type):
        """Setup required parameters.

        :param choice provider_type: 
        :param str provider_name: 
        :param choice msg_type: 

        :return: None
        :rtype: None
        """
        self.provider_type = provider_type
        self.provider_name = provider_name
        self.msg_type = msg_type



"""Kill user by ids info API method."""
from ibsng.handler.handler import Handler


class killUserByID(Handler):
    """Kill user by ids method class."""

    def control(self):
        """Validate inputs after setup method.

        :return: None
        :rtype: None
        """
        self.is_valid(self.user_id, str)
        self.is_valid_content(self.user_id, self.IDS_PATTERN)

    def setup(self, user_ids):
        """Setup required parameters.

        :param list user_ids: list of ibsng user ids

        :return: None
        :rtype: None
        """
        self.user_id = ",".join(map(str, user_ids))



""" info API method."""
from ibsng.handler.handler import Handler


class delReports(Handler):
    """ info method class."""

    def setup(self, table, date, date_unit):
        """Setup required parameters.

        :param str table: 
        :param str_datetime, float date: 
        :param choice date_unit: 
    
        :return: void
        :rtype: void
        """
        self.table = table
        self.date = date
        self.date_unit = date_unit



""" info API method."""
from ibsng.handler.handler import Handler


class getBWSnapShotForUserAjax(Handler):
    """ info method class."""

    def setup(self, from_=None, from_unit=None):
        """Setup required parameters.

        :param str from: by user
        :param str from_unit: 
    
        :return: void
        :rtype: void
        """
        self.from_ = from_
        self.from_unit = from_unit



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class getProviderUnassignedEPs(Handler):
    """Message Center info method class."""

    def setup(self, provider_name, count, starts_with):
        """Setup required parameters.

        :param str provider_name: 
        :param int count: 
        :param str starts_with: 
    
        :return: void
        :rtype: void
        """
        self.provider_name = provider_name
        self.count = count
        self.starts_with = starts_with



""" info API method."""
from ibsng.handler.handler import Handler


class getConnections(Handler):
    """ info method class."""

    def setup(self, conds, from_, to_, sort_by, desc):
        """Setup required parameters.

        :param dict conds: 
        :param int from: start index, for pagination
        :param int to: end index, for pagination
        :param choice sort_by: 
        :param bool desc: descending
    
        :return: void
        :rtype: void
        """
        self.conds = conds
        self.from_ = from_
        self.to_ = to_
        self.sort_by = sort_by
        self.desc = desc



""" info API method."""
from ibsng.handler.handler import Handler


class getCurrentCredit(Handler):
    """ info method class."""

    def setup(self, user_id):
        """Setup required parameters.

        :param int user_id: 
    
        :return: void
        :rtype: void
        """
        self.user_id = user_id



""" info API method."""
from ibsng.handler.handler import Handler


class getOnlineUsersCountLoop(Handler):
    """ info method class."""

    def setup(self, conds=None):
        """Setup required parameters.

        :param dict conds: the same as getOnlineUsers
    
        :return: void
        :rtype: void
        """
        self.conds = conds



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class addNewEPGroupToProvider(Handler):
    """Message Center info method class."""

    def setup(self, end_point_range, provider_name):
        """Setup required parameters.

        :param str end_point_range: comma-seperated end-point groups
        :param str provider_name: provider name

        :return: None
        :rtype: None
        """
        self.end_point_range = end_point_range
        self.provider_name = provider_name



""" info API method."""
from ibsng.handler.handler import Handler


class updateNotificationRule(Handler):
    """ info method class."""

    def setup(self, notification_rule_id, notification_profile_id, notification_type, notification_threshold, message_type, message_template):
        """Setup required parameters.

        :param int notification_rule_id: 
        :param int notification_profile_id: 
        :param choice notification_type: 
        :param float notification_threshold: 
        :param choice message_type: 
        :param str message_template: 
    
        :return: void
        :rtype: void
        """
        self.notification_rule_id = notification_rule_id
        self.notification_profile_id = notification_profile_id
        self.notification_type = notification_type
        self.notification_threshold = notification_threshold
        self.message_type = message_type
        self.message_template = message_template



""" info API method."""
from ibsng.handler.handler import Handler


class authenticate(Handler):
    """ info method class."""

    def setup(self, auth_by, auth_id):
        """Setup required parameters.

        :param choice auth_by: 
        :param str auth_id: 
    
        :return: void
        :rtype: void
        """
        self.auth_by = auth_by
        self.auth_id = auth_id



""" info API method."""
from ibsng.handler.handler import Handler


class getRequestTopStats(Handler):
    """ info method class."""

    def setup(self, order_by):
        """Setup required parameters.

        :param choice order_by: 
    
        :return: void
        :rtype: void
        """
        self.order_by = order_by



""" info API method."""
from ibsng.handler.handler import Handler


class purgePayment(Handler):
    """ info method class."""

    def setup(self, payment_id):
        """Setup required parameters.

        :param int payment_id: 
    
        :return: void
        :rtype: void
        """
        self.payment_id = payment_id



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class getProviderInfoByName(Handler):
    """Message Center info method class."""

    def setup(self, provider_name):
        """Setup required parameters.

        :param str provider_name: 
    
        :return: void
        :rtype: void
        """
        self.provider_name = provider_name



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class receive(Handler):
    """Message Center info method class."""

    def setup(self, msg_info):
        """Setup required parameters.

        :param dict msg_info: 
    
        :return: void
        :rtype: void
        """
        self.msg_info = msg_info



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class adminCancelScheduledMessages(Handler):
    """Message Center info method class."""

    def setup(self, message_ids):
        """Setup required parameters.

        :param list message_ids: message ids

        :return: None
        :rtype: None
        """
        self.message_ids = ",".join(map(str,message_ids))



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class getActiveMSGTypes(Handler):
    """Message Center info method class."""

    def setup(self, view_type):
        """Setup required parameters.

        :param choice view_type: 
    
        :return: void
        :rtype: void
        """
        self.view_type = view_type



"""Realtime snapshot API method."""
from ibsng.handler.handler import Handler


class getRealTimeSnapShotAjax(Handler):
    """Realtime snapshot method."""

    def setup(self, name, from_, from_unit, ras_ips='', date_type='jalali'):
        """Setup required parameters.

        :param str name: name
        :param int from_: from as hour
        :param str unit: unit ex: hours

        :return: void
        :rtype: void
        """
        self.name = name
        self.from_ = from_
        self.from_unit = from_unit
        self.ras_ips = ras_ips
        self.date_type = date_type



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class adminSearchReceivedMessage(Handler):
    """Message Center info method class."""

    def setup(self, conds, from_index, to_index, order_by, desc):
        """Setup required parameters.

        :param dict conds: conditions
        :param int from: page start index
        :param int to: page end index
        :param choice order_by: order by specific field
        :param bool desc: descending
    
        :return: None
        :rtype: None
        """
        self.conds = conds
        self.from_ = from_index
        self.to_ = to_index
        self.order_by = order_by
        self.desc = desc



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class removeEPGroupFromProvider(Handler):
    """Message Center info method class."""

    def setup(self, provider_id, end_point_group_id):
        """Setup required parameters.

        :param int provider_id: 
        :param int end_point_group_id: 
    
        :return: void
        :rtype: void
        """
        self.provider_id = provider_id
        self.end_point_group_id = end_point_group_id



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class enqueueSend(Handler):
    """Message Center info method class."""

    def setup(self, body, destinations, msg_type, schedule_date, schedule_date_unit=None):
        """Setup required parameters.

        :param str body: 
        :param str destinations: comma-seperated list of destinations
        :param choice msg_type: 
        :param str_datetime, float schedule_date: 
        :param choice schedule_date_unit: 
    
        :return: void
        :rtype: void
        """
        self.body = body
        self.destinations = destinations
        self.msg_type = msg_type
        self.schedule_date = schedule_date
        self.schedule_date_unit = schedule_date_unit



""" info API method."""
from ibsng.handler.handler import Handler


class verifyPayment(Handler):
    """ info method class."""

    def setup(self, unique_id, web_attributes):
        """Setup required parameters.

        :param str unique_id: 
        :param dict web_attributes: 
    
        :return: void
        :rtype: void
        """
        self.unique_id = unique_id
        self.web_attributes = web_attributes



""" info API method."""
from ibsng.handler.handler import Handler


class callerIDAuthenticate(Handler):
    """ info method class."""

    def setup(self, caller_id):
        """Setup required parameters.

        :param str caller_id: 
    
        :return: void
        :rtype: void
        """
        self.caller_id = caller_id



""" info API method."""
from ibsng.handler.handler import Handler


class saveCreditChanges(Handler):
    """ info method class."""

    def setup(self, conds, cols, sort_by, desc, output_type):
        """Setup required parameters.

        :param dict conds: the same as getCreditChanges
        :param list cols: 
        :param choice sort_by: 
        :param bool desc: descending
        :param choice output_type: 
    
        :return: void
        :rtype: void
        """
        self.conds = conds
        self.cols = cols
        self.sort_by = sort_by
        self.desc = desc
        self.output_type = output_type



""" info API method."""
from ibsng.handler.handler import Handler


class autoCleanReports(Handler):
    """ info method class."""

    def setup(self, connection_log_clean, connection_log_unit, credit_change_clean, credit_change_unit, user_audit_log_clean, user_audit_log_unit, snapshots_clean, snapshots_unit, bw_snapshots_clean, bw_snapshots_unit, web_analyzer_clean, web_analyzer_unit):
        """Setup required parameters.

        :param int connection_log_clean: period
        :param choice connection_log_unit: 
        :param int credit_change_clean: relative time
        :param choice credit_change_unit: relative time unit
        :param int user_audit_log_clean: relative time
        :param choice user_audit_log_unit: relative time unit
        :param int snapshots_clean: relative time
        :param choice snapshots_unit: relative time unit
        :param int bw_snapshots_clean: relative time
        :param choice bw_snapshots_unit: relative time unit
        :param int web_analyzer_clean: relative time
        :param choice web_analyzer_unit: relative time unit
    
        :return: void
        :rtype: void
        """
        self.connection_log_clean = connection_log_clean
        self.connection_log_unit = connection_log_unit
        self.credit_change_clean = credit_change_clean
        self.credit_change_unit = credit_change_unit
        self.user_audit_log_clean = user_audit_log_clean
        self.user_audit_log_unit = user_audit_log_unit
        self.snapshots_clean = snapshots_clean
        self.snapshots_unit = snapshots_unit
        self.bw_snapshots_clean = bw_snapshots_clean
        self.bw_snapshots_unit = bw_snapshots_unit
        self.web_analyzer_clean = web_analyzer_clean
        self.web_analyzer_unit = web_analyzer_unit



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class dialerDeleteMessage(Handler):
    """Message Center info method class."""

    def setup(self, message_id):
        """Setup required parameters.

        :param int message_id: 
    
        :return: void
        :rtype: void
        """
        self.message_id = message_id



"""Can do info API method."""
from ibsng.handler.handler import Handler


class canDo(Handler):
    """Can do info method class."""

    def control(self):
        """Validate inputs after method setup.

        :return: None
        :rtype: None
        """
        self.is_valid(self.perm_name, str)
        self.is_valid(self.admin_username, str)
        self.is_valid(self.params, list)

    def setup(self, perm_name, admin_username, params):
        """Setup required parameters.

        :param str perm_name: permission name
        :param str admin_username: admin username
        :param list params: parameter list

        :return: None
        :rtype: None
        """
        self.perm_name = perm_name
        self.admin_username = admin_username
        self.params = params



""" info API method."""
from ibsng.handler.handler import Handler


class preparePayment(Handler):
    """ info method class."""

    def setup(self, gateway_type, amount, unique_id, callback_url, attributes):
        """Setup required parameters.

        :param choice gateway_type: 
        :param float amount: 
        :param str unique_id: 
        :param str callback_url: 
        :param dict attributes: you can put all the parameters you want here
    
        :return: void
        :rtype: void
        """
        self.gateway_type = gateway_type
        self.amount = amount
        self.unique_id = unique_id
        self.callback_url = callback_url
        self.attributes = attributes



""" info API method."""
from ibsng.handler.handler import Handler


class updateGateway(Handler):
    """ info method class."""

    def setup(self, gateway_id, gateway_name, owner_isp_name, priority, comment, attributes):
        """Setup required parameters.

        :param int gateway_id: 
        :param str gateway_name: 
        :param str owner_isp_name: 
        :param int priority: 
        :param str comment: 
        :param dict attributes: 
    
        :return: void
        :rtype: void
        """
        self.gateway_id = gateway_id
        self.gateway_name = gateway_name
        self.owner_isp_name = owner_isp_name
        self.priority = priority
        self.comment = comment
        self.attributes = attributes



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class activateService(Handler):
    """Message Center info method class."""

    def setup(self, cell_number):
        """Setup required parameters.

        :param str cell_number: cell phone number

        :return: None
        :rtype: None
        """
        self.cell_number = cell_number



""" info API method."""
from ibsng.handler.handler import Handler


class getDayNightUsage(Handler):
    """ info method class."""

    def setup(self, start_date, end_date, nightly_charge_rule_ids):
        """Setup required parameters.

        :param str start_date: gregorian date, format '%Y-%m-%d'
        :param str end_date: gregorian date, format '%Y-%m-%d'
        :param list nightly_charge_rule_ids: list of Charge Rule IDs that are Nightly (Free)
    
        :return: void
        :rtype: void
        """
        self.start_date = start_date
        self.end_date = end_date
        self.nightly_charge_rule_ids = nightly_charge_rule_ids



"""Copy group API method."""
from ibsng.handler.handler import Handler


class copyGroup(Handler):
    """Copy group info method class."""

    def control(self):
        """Validate inputs after setup method.

        :return: None
        :rtype: None
        """
        self.is_valid(self.group_name, str)
        self.is_valid(self.isp_name, str)
        self.is_valid(self.copy_count, int)
        self.is_valid(self.comment, str, False)

    def setup(self, group_name, isp_name, copy_count, comment=""):
        """Setup required parameters.

        :param str group_name: group name
        :param str isp_name: isp name
        :param int copy_count: count of copy
        :param str comment: group comment

        :return: None
        :rtype: None
        """
        self.group_name = group_name
        self.isp_name = isp_name
        self.copy_count = copy_count
        self.comment = comment



""" info API method."""
from ibsng.handler.handler import Handler


class getOnlineUsers(Handler):
    """ info method class."""

    def setup(self, normal_sort_by, normal_desc, voip_sort_by, voip_desc, conds):
        """Setup required parameters.

        :param choice normal_sort_by: 
        :param bool normal_desc: descending
        :param choice voip_sort_by: 
        :param bool voip_desc: descending
        :param dict conds: 
    
        :return: void
        :rtype: void
        """
        self.normal_sort_by = normal_sort_by
        self.normal_desc = normal_desc
        self.voip_sort_by = voip_sort_by
        self.voip_desc = voip_desc
        self.conds = conds



"""Message Center info API method."""
from ibsng.handler.handler import Handler


class updateUserRemoteRequestAttrs(Handler):
    """Message Center info method class."""

    def setup(self, remote_report_status, remote_report_command, allowed_requesters, attrs):
        """Setup required parameters.

        :param str remote_report_status: 
        :param str remote_report_command: 
        :param str allowed_requesters: 
        :param dict attrs: 
    
        :return: void
        :rtype: void
        """
        self.remote_report_status = remote_report_status
        self.remote_report_command = remote_report_command
        self.allowed_requesters = allowed_requesters
        self.attrs = attrs
